==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/space/messages/de/base.php <==
<?php
return array (
  '<b>This space is still empty!</b>' => '<b>Dieser Space ist noch leer!</b>',
  '<b>This space is still empty!</b><br>Start by posting something here...' => '<strong>Dieser Space ist noch leer!</strong><br />Mache den Anfang und teile etwas mit ...',
  '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Du bist noch kein Mitglied dieses Spaces. Derzeit liegen keinen öffentlichen Inhalte vor!</b>',
  '<strong>About</strong> the Space' => '<strong>Über</strong> diesen Space',
  '<strong>About</strong> your membership' => '<strong>Über</strong> deine Rolle',
  '<strong>Confirm</strong> image deletion' => 'Löschen des Bildes <strong>bestätigen</strong>',
  '<strong>Invite</strong> members' => 'Mitglieder <strong>einladen</strong>',
  '<strong>New</strong> member request' => '<strong>Neuer</strong> Mitgliedsantrag',
  '<strong>New</strong> spaces' => '<strong>Neue</strong> Spaces',
  '<strong>Request</strong> Membership' => 'Space-Mitgliedschaft <strong>beantragen</strong>',
  '<strong>Space</strong> followers' => '<strong>Space</strong>-Follower',
  '<strong>Space</strong> members' => '<strong>Space</strong>-Mitglieder',
  '<strong>Space</strong> menu' => '<strong>Space</strong>-Menü',
  '<strong>Space</strong> tags' => '<strong>Space</strong> tags',
  '<strong>Spaces</strong>' => '<strong>Spaces</strong>',
  'About' => 'Über',
  'Accept' => 'Akzeptieren',
  'Accept Invite' => 'Einladung annehmen',
  'Access to this Space is restricted. Please introduce yourself to become a member.' => 'Um bestätigtes Mitglied dieses Spaces zu werden, stelle dich bitte kurz vor.',
  'Add users without invitation' => 'Benutzer ohne Einladung hinzufügen',
  'Admin' => 'Admin',
  'Administrator:' => 'Administrator:',
  'Administrators' => 'Administratoren',
  'Any' => 'Alle',
  'Archived' => 'Archiviert',
  'As owner you cannot revoke your membership!' => 'Als Eigentümer des Spaces kannst du deine Mitgliedschaft nicht beenden!',
  'Blocked users' => 'Blockierte Benutzer',
  'By Name' => 'Alphabetisch',
  'Cancel' => 'Abbrechen',
  'Close' => 'Schließen',
  'Color' => 'Farbe',
  'Could not request membership!' => 'Mitgliedschaft konnte nicht beantragt werden!',
  'Created At' => 'Erstellt am',
  'Created By' => 'Erstellt von',
  'Decline' => 'Ablehnen',
  'Decline Invite' => 'Einladung ablehnen',
  'Default' => 'Standard',
  'Default content visibility' => 'Standard-Sichtbarkeit der Inhalte',
  'Delete' => 'Löschen',
  'Description' => 'Beschreibung',
  'Do you really want to delete your profile image?' => 'Möchtest du wirklich dein Profilbild löschen?',
  'Do you really want to delete your title image?' => 'Möchtest du wirklich dein Titelbild löschen?',
  'Done' => 'Abgeschlossen',
  'Email addresses' => 'E-Mail-Adressen',
  'Everyone can enter' => 'Jeder kann beitreten',
  'Find Spaces by their description or by their tags' => 'Finde Spaces anhand Ihrer Beschreibung oder anhand Ihrer "Tags"',
  'Follow' => 'Folgen',
  'Followers' => 'Follower',
  'Following' => 'Folgend',
  'Guests' => 'Gäste',
  'Hide About Page' => '"Über" Seite verbergen',
  'Hide Activity Sidebar Widget' => 'Aktivitäten Widget in der Seitenleiste verbergen',
  'Hide Followers' => 'Follower verbergen',
  'Hide Members' => 'Mitglieder verbergen',
  'Homepage' => 'Homepage',
  'Homepage (Guests)' => 'Homepage (Gäste)',
  'I want to become a member because...' => 'Ich möchte Mitglied werden, weil...',
  'Invite' => 'Einladen',
  'Invite and request' => 'Einladung und Anfrage',
  'Invite by email' => 'Per E-Mail einladen',
  'Invites' => 'Einladungen',
  'Join' => 'Beitreten',
  'Join Policy' => 'Beitritts-Richtlinie',
  'Last Visit' => 'Letzter Besuch',
  'Login' => 'Login',
  'Max. 100 characters.' => 'Max. 100 Zeichen.',
  'Member' => 'Mitglied',
  'Member since' => 'Mitglied seit',
  'Members' => 'Mitglieder',
  'Moderator' => 'Moderator',
  'Moderator:' => 'Moderator:',
  'Moderators' => 'Moderatoren',
  'My Space List' => 'Meine Spaces',
  'My space summary' => 'Meine Space-Zusammenfassung',
  'Name' => 'Name',
  'Neither..nor' => 'Weder..noch',
  'New user by e-mail (comma separated)' => 'Neue Benutzer per E-Mail (getrennt durch Kommas)',
  'New user?' => 'Neuer Benutzer?',
  'Newest first' => 'Neueste zuerst',
  'No results found!' => 'Keine Ergebnisse gefunden!',
  'No spaces found.' => 'Keine Spaces gefunden.',
  'Oldest first' => 'Älteste zuerst',
  'Only by invite' => 'Nur auf Einladung',
  'Originator User ID' => 'Ersteller Benutzer ID',
  'Owner' => 'Besitzer',
  'Owner:' => 'Besitzer:',
  'Pending' => 'Ausstehend',
  'Pick users' => 'Benutzer auswählen',
  'Posts' => 'Beiträge',
  'Private' => 'Privat',
  'Private (Invisible)' => 'Privat (unsichtbar)',
  'Public' => 'Öffentlich',
  'Public (Members & Guests)' => 'Öffentlich (auch nicht registrierte Besucher)',
  'Public (Members only)' => 'Öffentlich (Nur Mitglieder)',
  'Public (Registered users only)' => 'Öffentlich (Nur registrierte Benutzer)',
  'Request Message' => 'Anfragenachricht',
  'Role' => 'Rolle',
  'Search...' => 'Suchen..',
  'See all' => 'Zeige alle',
  'Select all registered users' => 'Alle registrierten Benutzer auswählen',
  'Send' => 'Senden',
  'Settings' => 'Einstellungen',
  'Settings could not be saved!' => 'Einstellungen konnten nicht gespeichert werden!',
  'Show all' => 'Alle anzeigen',
  'Show as List' => 'Als Liste anzeigen',
  'Shown on About Page.' => 'Wird auf Informationsseite angezeigt.',
  'Sorry, you are not allowed to leave this space!' => 'Sorry, aber du kannst diesen Space nicht verlassen.',
  'Sorting' => 'Sortierung',
  'Space' => 'Space',
  'Space Visibility' => 'Space Sichtbarkeit',
  'Space directory' => 'Space-Verzeichnis',
  'Space is invisible!' => 'Space ist unsichtbar!',
  'Spaces' => 'Spaces',
  'Status' => 'Status',
  'Stream' => 'Stream',
  'Tags' => 'Tags',
  'There is no pending invite!' => 'Keine ausstehenden Einladungen!',
  'This action is only available for workspace members!' => 'Diese Aktion ist nur für Space-Mitglieder verfügbar!',
  'This user is already a member of this space.' => 'Dieser Benutzer ist bereits Miglied dieses Space.',
  'This user is not a member of this space.' => 'Dieser Benutzer ist kein Mitglied dieses Space.',
  'To invite users to this space, please type their names below to find and pick them.' => 'Um Benutzer in diesen Space einzuladen, gib deren Name unten ein, um sie zu suchen und auszuwählen.',
  'Try other keywords or remove filters.' => 'Verwende andere Suchbegriffe oder ändere die Filtereinstellungen.',
  'Updated At' => 'Geändert am',
  'Updated By' => 'Aktualisiert von',
  'Updated by' => 'Geändert von',
  'User \'{username}\' is already a member of this space!' => 'Der Benutzer \'{username}\' ist bereits Mitglied des Spaces!',
  'User invitations have been added to the queue' => 'Benutzereinladungen wurden der Warteschlange hinzugefügt.',
  'User memberships have been added to the queue' => 'Benutzerzugehörigkeiten wurden der Warteschlange hinzugefügt.',
  'User not found!' => 'Benutzer nicht gefunden!',
  'Users' => 'Benutzer',
  'Users has been invited.' => 'Benutzer wurden eingeladen.',
  'Visibility' => 'Sichtbarkeit',
  'Visible for all (members and guests)' => 'Sichtbar für alle (auch ohne Benutzerkonto)',
  'Would you like to end your membership in Space {spaceName}?' => 'Möchtest du deine Mitgliedschaft in dem Space {spaceName} wirklich beenden?',
  'Would you like to unfollow Space {spaceName}?' => 'Möchtest du dem Space {spaceName} wirklich aufhören zu folgen?',
  'Would you like to unfollow {userName}?' => 'Möchtest du wirklich aufhören {userName} zu folgen?',
  'Would you like to withdraw your request to join Space {spaceName}?' => 'Möchtest du deine Anfrage dem Space {spaceName} beizutreten wirklich zurückziehen?',
  'You are not allowed to join this space!' => 'Du darfst diesem Space nicht betreten!',
  'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => 'Du kannst auch externe Benutzer einladen, die noch nicht registriert sind. Gib einfach ihre E-Mail-Adressen ein, durch Kommata getrennt.',
  'You cannot create private visible spaces!' => 'Du kannst keine privaten Spaces erstellen!',
  'You cannot create public visible spaces!' => 'Du kannst keine öffentlichen Spaces erstellen!',
  'You need to login to view contents of this space!' => 'Du musst dich einloggen, um die Inhalte dieses Spaces sehen zu können!',
  'Your Message' => 'Anwendungsmeldung',
  'Your request was successfully submitted to the space administrators.' => 'Deine Anfrage wurde erfolgreich an die Space-Administratoren weitergeleitet.',
  '{count} members' => '{count} Mitglieder',
  '{email} is not valid!' => '{email} ist ungültig!',
);

==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/space/messages/de/base.php <==
<?php
return array (
  '<b>This space is still empty!</b>' => '<b>Dieser Space ist noch leer!</b>',
  '<b>This space is still empty!</b><br>Start by posting something here...' => '<strong>Dieser Space ist noch leer!</strong><br />Mache den Anfang und teile etwas mit ...',
  '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Du bist noch kein Mitglied dieses Spaces. Derzeit liegen keinen öffentlichen Inhalte vor!</b>',
  '<strong>About</strong> the Space' => '<strong>Über</strong> diesen Space',
  '<strong>About</strong> your membership' => '<strong>Über</strong> deine Rolle',
  '<strong>Confirm</strong> image deletion' => 'Löschen des Bildes <strong>bestätigen</strong>',
  '<strong>Invite</strong> members' => 'Mitglieder <strong>einladen</strong>',
  '<strong>New</strong> member request' => '<strong>Neuer</strong> Mitgliedsantrag',
  '<strong>New</strong> spaces' => '<strong>Neue</strong> Spaces',
  '<strong>Request</strong> Membership' => 'Space-Mitgliedschaft <strong>beantragen</strong>',
  '<strong>Space</strong> followers' => '<strong>Space</strong>-Follower',
  '<strong>Space</strong> members' => '<strong>Space</strong>-Mitglieder',
  '<strong>Space</strong> menu' => '<strong>Space</strong>-Menü',
  '<strong>Space</strong> tags' => '<strong>Space</strong> tags',
  '<strong>Spaces</strong>' => '<strong>Spaces</strong>',
  'About' => 'Über',
  'Accept' => 'Akzeptieren',
  'Accept Invite' => 'Einladung annehmen',
  'Access to this Space is restricted. Please introduce yourself to become a member.' => 'Um bestätigtes Mitglied dieses Spaces zu werden, stelle dich bitte kurz vor.',
  'Add users without invitation' => 'Benutzer ohne Einladung hinzufügen',
  'Admin' => 'Admin',
  'Administrator:' => 'Administrator:',
  'Administrators' => 'Administratoren',
  'Any' => 'Alle',
  'Archived' => 'Archiviert',
  'As owner you cannot revoke your membership!' => 'Als Eigentümer des Spaces kannst du deine Mitgliedschaft nicht beenden!',
  'Blocked users' => 'Blockierte Benutzer',
  'By Name' => 'Alphabetisch',
  'Cancel' => 'Abbrechen',
  'Close' => 'Schließen',
  'Color' => 'Farbe',
  'Could not request membership!' => 'Mitgliedschaft konnte nicht beantragt werden!',
  'Create new link' => 'Neuen Link erzeugen',
  'Created At' => 'Erstellt am',
  'Created By' => 'Erstellt von',
  'Decline' => 'Ablehnen',
  'Decline Invite' => 'Einladung ablehnen',
  'Default' => 'Standard',
  'Default content visibility' => 'Standard-Sichtbarkeit der Inhalte',
  'Delete' => 'Löschen',
  'Description' => 'Beschreibung',
  'Do you really want to delete your profile image?' => 'Möchtest du wirklich dein Profilbild löschen?',
  'Do you really want to delete your title image?' => 'Möchtest du wirklich dein Titelbild löschen?',
  'Done' => 'Abgeschlossen',
  'Email addresses' => 'E-Mail-Adressen',
  'Everyone can enter' => 'Jeder kann beitreten',
  'Find Spaces by their description or by their tags' => 'Finde Spaces anhand Ihrer Beschreibung oder anhand Ihrer "Tags"',
  'Follow' => 'Folgen',
  'Followers' => 'Follower',
  'Following' => 'Folgend',
  'Guests' => 'Gäste',
  'Hide About Page' => '"Über" Seite verbergen',
  'Hide Activity Sidebar Widget' => 'Aktivitäten Widget in der Seitenleiste verbergen',
  'Hide Followers' => 'Follower verbergen',
  'Hide Members' => 'Mitglieder verbergen',
  'Homepage' => 'Homepage',
  'Homepage (Non-members)' => 'Homepage (Nicht-Mitglieder)',
  'I want to become a member because...' => 'Ich möchte Mitglied werden, weil...',
  'Invite' => 'Einladen',
  'Invite and request' => 'Einladung und Anfrage',
  'Invite by email' => 'Per E-Mail einladen',
  'Invite by link' => 'Per Link einladen',
  'Invite link' => 'Einladungslink',
  'Invites' => 'Einladungen',
  'Join' => 'Beitreten',
  'Join Policy' => 'Beitritts-Richtlinie',
  'Last Visit' => 'Letzter Besuch',
  'Login' => 'Login',
  'Max. 100 characters.' => 'Max. 100 Zeichen.',
  'Member' => 'Mitglied',
  'Member since' => 'Mitglied seit',
  'Members' => 'Mitglieder',
  'Moderator' => 'Moderator',
  'Moderator:' => 'Moderator:',
  'Moderators' => 'Moderatoren',
  'My Space List' => 'Meine Spaces',
  'My space summary' => 'Meine Space-Zusammenfassung',
  'Name' => 'Name',
  'Neither..nor' => 'Weder..noch',
  'New user by e-mail (comma separated)' => 'Neue Benutzer per E-Mail (getrennt durch Kommas)',
  'New user?' => 'Neuer Benutzer?',
  'Newest first' => 'Neueste zuerst',
  'No results found!' => 'Keine Ergebnisse gefunden!',
  'No spaces found.' => 'Keine Spaces gefunden.',
  'Oldest first' => 'Älteste zuerst',
  'Only by invite' => 'Nur auf Einladung',
  'Originator User ID' => 'Ersteller Benutzer ID',
  'Owner' => 'Besitzer',
  'Owner:' => 'Besitzer:',
  'Pending' => 'Ausstehend',
  'Pick users' => 'Benutzer auswählen',
  'Please note that any links you have previously created will become invalid as soon as you create a new one. Would you like to proceed?' => 'Bitte beachte, dass alle zuvor erstellten Links ungültig werden, sobald ein neuer Link generiert wird. Möchtest du fortfahren?',
  'Posts' => 'Beiträge',
  'Private' => 'Privat',
  'Private (Invisible)' => 'Privat (unsichtbar)',
  'Public' => 'Öffentlich',
  'Public (Members & Guests)' => 'Öffentlich (auch nicht registrierte Besucher)',
  'Public (Members only)' => 'Öffentlich (Nur Mitglieder)',
  'Public (Registered users only)' => 'Öffentlich (Nur registrierte Benutzer)',
  'Request Message' => 'Anfragenachricht',
  'Role' => 'Rolle',
  'Search...' => 'Suchen..',
  'See all' => 'Zeige alle',
  'Select all registered users' => 'Alle registrierten Benutzer auswählen',
  'Send' => 'Senden',
  'Send the link via email' => 'Link per E-Mail versenden',
  'Settings' => 'Einstellungen',
  'Settings could not be saved!' => 'Einstellungen konnten nicht gespeichert werden!',
  'Show all' => 'Alle anzeigen',
  'Show as List' => 'Als Liste anzeigen',
  'Shown on About Page.' => 'Wird auf Informationsseite angezeigt.',
  'Sorry, you are not allowed to leave this space!' => 'Sorry, aber du kannst diesen Space nicht verlassen.',
  'Sorting' => 'Sortierung',
  'Space' => 'Space',
  'Space Visibility' => 'Space Sichtbarkeit',
  'Space directory' => 'Space-Verzeichnis',
  'Space is invisible!' => 'Space ist unsichtbar!',
  'Spaces' => 'Spaces',
  'Status' => 'Status',
  'Stream' => 'Stream',
  'Tags' => 'Tags',
  'The default homepage for members of this Space' => 'Die Homepage für Mitglieder dieses Spaces.',
  'The default homepage for non-members and guests visiting this Space' => 'Die Homepage für Nicht-Mitglieder dieses Spaces und Gäste.',
  'The secure link has been copied in your clipboard!' => 'Der Link wurde in deine Zwischenablage kopiert!',
  'There is no pending invite!' => 'Keine ausstehenden Einladungen!',
  'This action is only available for workspace members!' => 'Diese Aktion ist nur für Space-Mitglieder verfügbar!',
  'This user is already a member of this space.' => 'Dieser Benutzer ist bereits Miglied dieses Space.',
  'This user is not a member of this space.' => 'Dieser Benutzer ist kein Mitglied dieses Space.',
  'To invite users to this space, please type their names below to find and pick them.' => 'Um Benutzer in diesen Space einzuladen, gib deren Name unten ein, um sie zu suchen und auszuwählen.',
  'Try other keywords or remove filters.' => 'Verwende andere Suchbegriffe oder ändere die Filtereinstellungen.',
  'Updated At' => 'Geändert am',
  'Updated By' => 'Aktualisiert von',
  'Updated by' => 'Geändert von',
  'User \'{username}\' is already a member of this space!' => 'Der Benutzer \'{username}\' ist bereits Mitglied des Spaces!',
  'User invitations have been added to the queue' => 'Benutzereinladungen wurden der Warteschlange hinzugefügt.',
  'User memberships have been added to the queue' => 'Benutzerzugehörigkeiten wurden der Warteschlange hinzugefügt.',
  'User not found!' => 'Benutzer nicht gefunden!',
  'Users' => 'Benutzer',
  'Users has been invited.' => 'Benutzer wurden eingeladen.',
  'Visibility' => 'Sichtbarkeit',
  'Visible for all (members and guests)' => 'Sichtbar für alle (auch ohne Benutzerkonto)',
  'Would you like to end your membership in Space {spaceName}?' => 'Möchtest du deine Mitgliedschaft in dem Space {spaceName} wirklich beenden?',
  'Would you like to unfollow Space {spaceName}?' => 'Möchtest du dem Space {spaceName} wirklich aufhören zu folgen?',
  'Would you like to unfollow {userName}?' => 'Möchtest du wirklich aufhören {userName} zu folgen?',
  'Would you like to withdraw your request to join Space {spaceName}?' => 'Möchtest du deine Anfrage dem Space {spaceName} beizutreten wirklich zurückziehen?',
  'You are not allowed to join this space!' => 'Du darfst diesem Space nicht betreten!',
  'You can also invite external users by email, which are not registered now. Just add their e-mail addresses separated by comma.' => 'Du kannst auch externe Nutzer per E-Mail einladen. Füge einfach ihre E-Mail-Adressen durch ein Komma getrennt hinzu.',
  'You can invite external users who are currently not registered via link. All you need to do is share this secure link with them.' => 'Du kannst auch externe Nutzer per Link einladen. Alles, was du tun musst, ist, diesen sicheren Link mit ihnen zu teilen.',
  'You cannot create private visible spaces!' => 'Du kannst keine privaten Spaces erstellen!',
  'You cannot create public visible spaces!' => 'Du kannst keine öffentlichen Spaces erstellen!',
  'You need to login to view contents of this space!' => 'Du musst dich einloggen, um die Inhalte dieses Spaces sehen zu können!',
  'Your Message' => 'Anwendungsmeldung',
  'Your request was successfully submitted to the space administrators.' => 'Deine Anfrage wurde erfolgreich an die Space-Administratoren weitergeleitet.',
  '{count} members' => '{count} Mitglieder',
  '{email} is not valid!' => '{email} ist ungültig!',
);
